package abbot;

import java.util.*;
import java.io.File;
import junit.framework.*;
import junit.extensions.abbot.TestHelper;

public class UnitTestSuite extends junit.framework.TestSuite {

    private static TestSuite createSuite(Class cls) {
        try {
            java.lang.reflect.Method suiteMethod =
                cls.getMethod("suite", null);
            return (TestSuite)suiteMethod.invoke(null, null);
        }
        catch(Exception e) {
            return new TestSuite(cls);
        }
    }

    private static Collection findTestClasses(File file, String name) {
        if ("test".equals(name))
            return new ArrayList();

        Set set = new HashSet();
        File[] files = file.listFiles();
        if (files == null) {
            if (name.endsWith("Test.class")) {
                String className = name.substring(0, name.length()-6);
                try {
                    Class cls = Class.forName(className);
                    if (!set.contains(cls)) {
                        set.add(cls);
                    }
                }
                catch(ClassNotFoundException e) {
                    e.printStackTrace();
                }
            }
        }
        else {
            for (int i=0;i < files.length;i++) {
                Collection tests =
                    findTestClasses(files[i],
                                    "".equals(name)
                                    ? files[i].getName()
                                    : name + "." + files[i].getName());
                set.addAll(tests);
            }
        }
        return set;
    }

    public static Test suite() {
        String filter = System.getProperty("abbot.test.filter");
        if (filter == null)
            filter = "";

        // Any classes which should be run first or in some particular order
        // should be put here.  Otherwise test case suites are run in the
        // order the classes are added. 
        Class[] priority = new Class[] {
            abbot.tester.WindowTrackerTest.class,
            junit.extensions.abbot.ComponentTestFixtureTest.class,
            junit.extensions.abbot.ScriptTestSuiteTest.class,
            abbot.tester.RobotTest.class,
        };
        // This group has some strange interactions...
        /*
          abbot.editor.ComponentBrowserTest.class, //
          abbot.editor.ComponentNodeTest.class, //
          abbot.editor.ComponentTreeTest.class, //
          abbot.editor.recorder.JInternalFrameRecorderTest.class, //
          abbot.finder.BasicFinderTest.class, //
          abbot.tester.JInternalFrameTesterTest.class, //
        */
        // Now add everything else
        File file = new File(System.getProperty("user.dir")
                             + File.separator + "build"
                             + File.separator + "test-classes");
        TestSuite suite = new TestSuite();
        Set scanned = new HashSet();
        scanned.addAll(findTestClasses(file, ""));

        for (int i=0;i < priority.length;i++) {
            Class cls = priority[i];
            if (scanned.contains(cls)
                && cls.getName().indexOf(filter) != -1) {
                suite.addTest(createSuite(cls));
            }
        }
        scanned.removeAll(Arrays.asList(priority));
        Iterator iter = scanned.iterator();
        while (iter.hasNext()) {
            Class cls = (Class)iter.next();
            if (cls.getName().indexOf(filter) != -1) {
                suite.addTest(createSuite(cls));
            }
        }
        return suite;
    }

    public UnitTestSuite(String name) { super(name); }

    public static void main(String[] args) {
        TestHelper.runTests(args, UnitTestSuite.class);
    }
}
