package abbot.editor;

import java.awt.*;
import javax.swing.*;
import javax.swing.table.*;
import javax.swing.tree.*;

import junit.extensions.abbot.*;
import abbot.script.Resolver;
import abbot.finder.*;
import abbot.finder.matchers.*;

public class ComponentTreeTest extends ComponentTestFixture {

    private ComponentTree tree;

    protected void setUp() {
        tree = new ComponentTree(new CompactHierarchy(getHierarchy()));
    }

    protected void tearDown() {
        Container c = tree.getParent();
        if (c != null)
            c.remove(tree);
        tree = null;
        // Get rid of the event listener
        System.gc();
    }

    private void assertPath(Object[] expected, Object[] path) {
        for (int i=0;i < expected.length && i < path.length;i++) {
            assertEquals("Wrong path component " + i,
                         expected[i], ((ComponentNode)path[i]).getComponent());
        }
        assertEquals("Wrong path length", expected.length, path.length);
    }

    public void testDisplayNewFrames() {
        Frame f = showFrame(new JLabel(getName()));
        TreePath path = tree.getPath(f);
        assertPath(new Object[] { null, f }, path.getPath());
    }

    public void testRefreshOnPopup() {
        JLabel label = new JLabel(getName());
        showFrame(label);
        JPopupMenu popup = new JPopupMenu();        
        popup.add(new JMenuItem("nothing to see"));
        installPopup(label, popup);
        getRobot().showPopupMenu(label);
        assertTrue("Tree didn't update after popup shown",
                   tree.getPath(popup) != null);
    }

    public void testPreserveSelection() {
        JLabel label = new JLabel(getName());
        JFrame f = new JFrame(getName());
        f.getContentPane().add(label);
        showWindow(f);
        ComponentNode root = (ComponentNode)
            ((DefaultTreeModel)tree.getModel()).getRoot();
        TreePath path = root.getPath(label);
        tree.setSelectionPath(path);
        tree.reload();
        TreePath newPath = tree.getSelectionPath();
        assertTrue("Tree should still have a selection", newPath != null);
        assertTrue("path should be visible", tree.isVisible(newPath));
        assertPath(new Object[] { null, f, f.getContentPane(), label },
                   newPath.getPath());
    }

    public void testRefreshOnWindowEvents() {
        Frame f = showFrame(new JLabel(getName()));
        assertPath(new Object[] { null, f }, tree.getPath(f).getPath());
        Frame f2 = new JFrame(getName() + "2");
        showWindow(f);
        assertPath(new Object[] { null, f2 }, tree.getPath(f2).getPath());
    }

    public ComponentTreeTest(String name) { super(name); }
    public static void main(String[] args) {
        TestHelper.runTests(args, ComponentTreeTest.class);
    }
}
