package abbot.editor;

import javax.swing.*;
import java.awt.*;
import java.io.*;

import junit.extensions.abbot.*;
import junit.extensions.abbot.Timer;
import junit.framework.*;

import junit.extensions.abbot.*;
import junit.framework.TestCase;
import abbot.script.Script;

/** Tests for the script editor proper. */

public class ScriptEditorTest extends ComponentTestFixture {

    ScriptEditor editor;

    protected void setUp() {
        editor = new ScriptEditor() {
            protected boolean checkSaveBeforeClose() {
                return true;
            }
        };
    }

    protected void tearDown() {
        if (editor != null) {
            editor.dispose();
        }
        // Make sure we don't have any security managers left around
        // preventing exits
        System.setSecurityManager(null);
    }

    public void testSaveNestedScripts() throws Throwable {
        Script s1 = new Script(getHierarchy());
        Script s2 = new Script(getHierarchy());
        Script s3 = new Script(getHierarchy());
        s1.addStep(s2);
        s2.addStep(s3);
        s3.addStep(new Script(getHierarchy()));
        assertTrue("Script 1 should be marked dirty", s1.isDirty());
        assertTrue("Script 2 should be marked dirty", s2.isDirty());
        assertTrue("Script 3 should be marked dirty", s3.isDirty());
        editor.saveNestedScripts(s1);
        assertTrue("Script 1 should have been saved", !s1.isDirty());
        assertTrue("Script 2 should have been saved", !s2.isDirty());
        assertTrue("Script 3 should have been saved", !s3.isDirty());
    }

    /** Open a new, empty script. */
    public void testNewScript() throws Throwable {
        // Try a file that exists
        File file = File.createTempFile(getName(), ".xml");
        file.deleteOnExit();
        editor.newScript(file, false);
        // Default script should always get a launch + terminate
        Script script = (Script)editor.getResolverContext();
        assertTrue("Script should have a launch step",
                   script.hasLaunch());
        assertTrue("Script should have a terminate step",
                   script.hasTerminate());

        // Try a file that doesn't exist
        file = File.createTempFile(getName(), ".xml");
        file.delete();
        editor.newScript(file, false);
        file.deleteOnExit();
        script = (Script)editor.getResolverContext();
        assertTrue("Script should have a launch step",
                   script.hasLaunch());
        assertTrue("Script should have a terminate step",
                   script.hasTerminate());
    }

    /** Construct a test case with the given name. */
    public ScriptEditorTest(String name) { super(name); }

    /** Run the default test suite. */
    public static void main(String[] args) {
        TestHelper.runTests(args, ScriptEditorTest.class);
    }
}
