package abbot.editor.widgets;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import junit.extensions.abbot.*;
import abbot.tester.*;
import abbot.finder.*;
import abbot.finder.matchers.*;

public class TextFieldTest extends ComponentTestFixture {

    private TextField textField;
    private JTextComponentTester tester;

    protected void setUp() {
        tester = new JTextComponentTester();
        textField = new TextField("Basic Field");
        showFrame(textField);
    }

    public void testReplaceText() {
        tester.actionActionMap(textField, "select-all");
        tester.actionKeyString("replaced");
        String text = textField.getText();
        assertEquals("Text not replaced", "replaced", text);
    }

    public void testRevert() {
        class Flag { volatile boolean flag; String command; }
        final Flag fired = new Flag();
        String orig = textField.getText();
        tester.actionEnterText(textField, "new text");
        assertTrue("Text not entered", !textField.getText().equals(orig));
        textField.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                fired.flag = true;
                fired.command = e.getActionCommand();
            }
        });
        tester.actionKeyStroke(textField, KeyEvent.VK_ESCAPE);
        assertEquals("Text not reverted", orig, textField.getText());
        assertTrue("No action fired on revert", fired.flag);
        assertEquals("Wrong action command",
                     TextField.ACTION_TEXT_REVERTED, fired.command);
    }

    public void testSelectAllOnEnter() {
        String text = "new text";
        tester.actionEnterText(textField, text);
        tester.actionKeyStroke(textField, KeyEvent.VK_ENTER);
        assertEquals("Text should be selected",
                     text, textField.getSelectedText());
    }

    /** Construct a test case with the given name. */
    public TextFieldTest(String name) { super(name); }

    /** Run the default test suite. */
    public static void main(String[] args) {
        TestHelper.runTests(args, TextFieldTest.class);
    }
}
