package abbot.i18n;

import java.util.Locale;

import junit.extensions.abbot.TestHelper;

/** Test Resource loading. */
public class StringsTest extends junit.framework.TestCase {

    public void testMissingResource() throws Throwable {
        Locale oldLocale = Locale.getDefault();
        try {
            Locale.setDefault(Locale.FRENCH);
            String key = "NoSuchResource";
            String value = Strings.get(key);
            assertEquals("Missing resource will be a flagged key",
                         "#" + key + "#", value);
            
            key = "abbot.DefaultPropertiesLoaded";
            value = Strings.get(key);
            assertEquals("Missing i18n resource should get default value",
                         "yes", value);
        }
        finally {
            Locale.setDefault(oldLocale);
        }
    }

    public void testOptionalResource() throws Throwable {
        // Accelerator; may or may not be present
        String key = "Menu.acc";
        String value = Strings.get(key, true);
        assertNull("Non-existent, optional value should be null", value);
    }

    public StringsTest(String name) {
        super(name);
    }

    public static void main(String[] args) {
        TestHelper.runTests(args, StringsTest.class);
    }
}
