package abbot.script;

import java.lang.reflect.Method;
import java.awt.*;
import java.awt.event.*;
import java.util.HashMap;

import junit.extensions.abbot.*;
import abbot.finder.ComponentFinder;
import abbot.finder.Hierarchy;
import abbot.tester.ComponentLocation;

public class ActionTest extends ComponentTestFixture {

    public void testMethodFixing() throws Throwable {
        Action action = new Action(getResolver(), getName(),
                                   "Click", new String[0]);
        assertEquals("Method name should be fixed",
                     "actionClick", action.getMethodName());
    }

    private class FakeRef extends ComponentReference {
        public FakeRef(Resolver r) {
            super(r, Component.class, new HashMap());
        }
        // Fake the lookup; we don't care about the result
        public Component getComponent(Hierarchy h) { return null; }
    }

    private class MyAction extends Action {
        public MyAction(Resolver r, String method, String[] args) {
            super(r, getName(), method, args);
        }
        public Object[] getParameters() throws Exception {
            return evaluateParameters(getMethod(), getArguments());
        }
    }

    public void testVKPlusModifier() throws Exception {
        ComponentReference ref = new FakeRef(getResolver());
        MyAction action = new MyAction(getResolver(), "actionKeyStroke", 
                                       new String[] {
                                           ref.getID(), "VK_A", "SHIFT_MASK",
                                       });
        Object[] params = action.getParameters();
        assertEquals("Second parameter should be an integer",
                     new Integer(KeyEvent.VK_A), params[1]);
        assertEquals("Third parameter should be an integer",
                     new Integer(KeyEvent.SHIFT_MASK), params[2]);
    }

    public void testComponentPlusVK() throws Exception {
        ComponentReference ref = new ComponentReference(getResolver(),
                                                        Component.class,
                                                        new HashMap());
        MyAction action = new MyAction(getResolver(), "actionKeyStroke", 
                                       new String[] {
                                           ref.getID(), "VK_X",
                                       });
        Method method = action.getMethod();
        Class[] params = method.getParameterTypes();
        assertEquals("First parameter should be a Component",
                     Component.class, params[0]);
        assertEquals("Second parameter should be an integer",
                     int.class, params[1]);
    }

    public void testMultipleModifiers() throws Exception {
        MyAction action = new MyAction(getResolver(), "actionKeyStroke", 
                                       new String[] { 
                                           "VK_B",
                                           "SHIFT_MASK|ALT_MASK",
                                       });
        Object[] params = action.getParameters();
        assertEquals("First parameter should be an integer",
                     new Integer(KeyEvent.VK_B), params[0]);
        assertEquals("Second parameter should be an integer",
                     new Integer(KeyEvent.SHIFT_MASK|KeyEvent.ALT_MASK),
                     params[1]);
    }

    public void testVKArgument() throws Exception {
        MyAction action = new MyAction(getResolver(), "actionKeyStroke", 
                              new String[] { "VK_C", });
        Object[] params = action.getParameters();
        assertEquals("First parameter should be an integer",
                     new Integer(KeyEvent.VK_C), params[0]);
    }

    public void testComponentLocationMethod() throws Throwable {
        ComponentReference ref = new FakeRef(getResolver());
        MyAction action = new MyAction(getResolver(), "Click", new String[] {
            ref.getID(), "(0,0)"
        });
        String[] args = action.getArguments();
        assertEquals("Wrong component reference ID",
                     ref.getID(), args[0]);
        Object[] params = action.getParameters();
        assertEquals("Second parameter should be a ComponentLocation",
                     new ComponentLocation(new Point(0, 0)), params[1]);
    }

    public ActionTest(String name) { super(name); }

    public static void main(String[] args) {
        TestHelper.runTests(args, ActionTest.class);
    }
}

