package abbot.script;

import java.awt.Component;
import java.awt.Window;
import java.applet.*;
import java.util.*;

import junit.extensions.abbot.*;
import junit.extensions.abbot.Timer;
import abbot.finder.matchers.*;

public class AppletviewerTest extends ComponentTestFixture {

    public static class TestApplet extends Applet {
        public static volatile Applet instance = null;
        public void init() {
            setBackground(java.awt.Color.green);
            instance = this;
        }
        public void destroy() {
            instance = null;
        }
    }

    public void testLaunch() throws Throwable {
        Appletviewer viewer =
            new Appletviewer(getResolver(), getName(),
                             TestApplet.class.getName(),
                             new HashMap(), null, null, null);
        viewer.run();
        // Step should not return until the applet is visible
        assertTrue("Test applet should be instantiated after step run",
                   TestApplet.instance != null);
        assertTrue("Test applet should be visible",
                   TestApplet.instance.isShowing());
    }

    public void testGeneratedHTML() {
        HashMap map = new HashMap();
        map.put("name", "value");
        MyAppletviewer viewer = new MyAppletviewer(map);

        String html = viewer.generateHTML();
        assertTrue("Missing html tag: " + html,
                   html.startsWith("<html>"));
        assertTrue("Missing applet tag: " + html,
                   html.indexOf("<applet") != -1);
        assertTrue("Code param missing: " + html,
                   html.indexOf("code=\"" + TestApplet.class.getName()) != -1);
        assertTrue("Params missing: " + html,
                   html.indexOf("><param name=\"name\" value=\"value\"") != -1);
    }

    public void testClassLoader() throws Throwable {
        MyAppletviewer viewer = new MyAppletviewer(new HashMap());
        viewer.run();
        Component c =
            getFinder().find(new ClassMatcher(Applet.class, true));
        assertEquals("Appletviewer should provide the Applet's class loader",
                     c.getClass().getClassLoader(),
                     viewer.getContextClassLoader());
    }

    public void testDocumentBase() throws Throwable {
        MyAppletviewer viewer = new MyAppletviewer(new HashMap());
        viewer.run();
        Applet applet = (Applet)getFinder().
            find(new ClassMatcher(Applet.class, true));
        
        assertNotNull("Document base should not be null",
                      applet.getDocumentBase());
    }

    /*
    public void testThreadsDisposed() throws Throwable {
        MyAppletviewer viewer = new MyAppletviewer(new HashMap());
        viewer.run();
        viewer.run();
        viewer.run();
        Iterator iter = getHierarchy().getRoots().iterator();
        while (iter.hasNext()) {
            getHierarchy().dispose((Window)iter.next());
        }

        ThreadGroup group = Thread.currentThread().getThreadGroup();
        while (group.getParent() != null) {
            group = group.getParent();
        }
        int count = group.activeCount();
        Thread[] list = new Thread[count];
        count = group.enumerate(list);

        for (int i=0;i < list.length;i++) {
            Thread thread = list[i];
            if (thread != null) {
                String name = thread.getName();
                if (name != null && name.startsWith("AWT-EventQueue")
                    && name.indexOf("(abbot)") != -1) {
                    System.out.println("Thread " + thread + " still running");
                    assertFalse("Event dispatch thread " + thread
                                + " should not still be running",
                                thread.isAlive());
                }
            }
        }
    }
    */

    private class MyAppletviewer extends Appletviewer {
        public MyAppletviewer(Map map) {
            super(AppletviewerTest.this.getResolver(), getName(), 
                  TestApplet.class.getName(),
                  map, "CODEBASE", "ARCHIVE", null);
        }
        public String generateHTML() { return super.generateHTML(); }
    }

    public static void main(String[] args) {
        TestHelper.runTests(args, AppletviewerTest.class);
    }
}
