package abbot.util;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import junit.extensions.abbot.*;

public class EventNormalizerTest extends ComponentTestFixture {

    private class Listener implements AWTEventListener {
        public int disposedCount = 0;
        public void eventDispatched(AWTEvent e) {
            if (e.getID() == WindowEvent.WINDOW_CLOSED) {
                ++disposedCount;
            }
        }
    }

    public void testFilterDuplicateDispose() {
        EventNormalizer n = new EventNormalizer();
        Listener l = new Listener();
        n.startListening(l, WindowEvent.WINDOW_EVENT_MASK);
        Frame f = showFrame(new JLabel(getName()));
        f.dispose();
        getRobot().waitForIdle();
        assertEquals("One call to dispose should result in one event (1)",
                     1, l.disposedCount);
        f.dispose();
        getRobot().waitForIdle();
        assertEquals("Multiple dispose events should be filtered (1)",
                     1, l.disposedCount);

        l.disposedCount = 0;
        showWindow(f);
        f.dispose();
        // wait for dispose to finish
        getRobot().waitForIdle();
        assertEquals("One call to dispose should result in one event "
                     + "(component disposed and shown)",
                     1, l.disposedCount);
        f.dispose();
        getRobot().waitForIdle();
        assertEquals("Multiple dispose events should be filtered "
                     + "(component disposed and shown)",
                     1, l.disposedCount);
    }

    public EventNormalizerTest(String name) { super(name); }
    public static void main(String[] args) {
        TestHelper.runTests(args, EventNormalizerTest.class);
    }
}
